@@ -1,16 +1,16 @@
 from jsp_exp import Job
 from typing import List, Optional, Tuple
 
-# from .utils import backward
-# from .utils import forward
-# from .utils.feasibility import has_schedule
-# from .utils import jsp
+from .utils import backward
+from .utils import forward
+from .utils.feasibility import has_schedule
+from .utils import jsp
 
 
-from utils import backward
-from utils import forward
-from utils.feasibility import has_schedule
-from utils import jsp
+# from utils import backward
+# from utils import forward
+# from utils.feasibility import has_schedule
+# from utils import jsp
 
 DEBUG = False
 
